function solution = wiisolve (task, level)
% solution - an n-by-5 array where each row is a description
%            of one output face, the first number is the number
%            of the frame in which the face is found, and the
%            following 4 are x and y coordinates of the top-left
%            corner, followed by the width and the height of the
%            bounding box
% task   -   the number of the task, 1|2|3|4
% level  -   the number of the level, 1|2|3

switch (task)
    case 1
        switch (level)
            case 1
%                solution = task1_1('Path2t1l1-1.avi', 'task1ref1.bmp');
            case 2
%                solution = task1_2('Path2t1l2-1.avi', 'task1ref2.bmp');
            case 3
%                solution = task1_3('Path2t1l3-1.avi', 'task1ref2.bmp');
        end
    case 2
        switch (level)
            case 1
%                solution = task2_1('Path2t2l1-1.avi');
            case 2
%                solution = task2_2('Path2t2l2-1.avi');
            case 3
%                solution = task2_3('Path2t2l3-1.avi');
        end
    case 3
        switch (level)
            case 1
%                solution = task3_1('Path2t3l1-1.avi');
            case 2
%                solution = task3_2('Path2t3l2-1.avi');
            case 3
%                solution = task3_3('Path2t3l3-1.avi');
        end
    case 4
        switch (level)
            case 1
%                solution = task4_1('Path2t4l1-1.avi');
            case 2
%                solution = task4_2('Path2t4l2-1.avi');
            case 3
%                solution = task4_3('Path2t4l3-1.avi');
        end
end
